@@ -32,11 +32,13 @@
 namespace KDEPrivate
 {
 
-static const int AVATAR_HEIGHT = 50;
-static const int AVATAR_WIDTH = 50;
-static const int MAIN_LINKS_HEIGHT = 32;
-static const int SOCIAL_LINKS_HEIGHT = 26;
-static const int MAX_SOCIAL_LINKS = 9;
+enum {
+    AVATAR_HEIGHT = 50,
+    AVATAR_WIDTH = 50,
+    MAIN_LINKS_HEIGHT = 32,
+    SOCIAL_LINKS_HEIGHT = 26,
+    MAX_SOCIAL_LINKS = 9
+};
 
 KAboutApplicationPersonListDelegate::KAboutApplicationPersonListDelegate(
     QAbstractItemView *itemView,
@@ -123,7 +125,7 @@ void KAboutApplicationPersonListDelegate::updateItemWidgets(const QList<QWidget
         action = mainLinks->actions().at(EmailAction);
         action->setToolTip(i18nc("Action to send an email to a contributor",
                                  "Email contributor\n%1", profile.email()));
-        action->setData(QString::fromLatin1("mailto:%1").arg(profile.email()));
+        action->setData(QStringLiteral("mailto:%1").arg(profile.email()));
         action->setVisible(true);
     }
     if (!profile.homepage().isEmpty()) {
@@ -212,7 +214,7 @@ void KAboutApplicationPersonListDelegate::paint(QPainter *painter,
     int margin = option.fontMetrics.height() / 2;
 
     QStyle *style = QApplication::style();
-    style->drawPrimitive(QStyle::PE_Widget, &option, painter, 0);
+    style->drawPrimitive(QStyle::PE_Widget, &option, painter, nullptr);
 
     const KAboutApplicationPersonModel *model = qobject_cast< const KAboutApplicationPersonModel * >(index.model());
 
@@ -231,7 +233,7 @@ void KAboutApplicationPersonListDelegate::paint(QPainter *painter,
             painter->drawPixmap(point, pixmap);
 
             QPoint framePoint(point.x() - 5, point.y() - 5);
-            QPixmap framePixmap(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kxmlgui/pics/thumb_frame.png")));
+            QPixmap framePixmap(QStringLiteral(":/kxmlgui5/thumb_frame.png"));
             painter->drawPixmap(framePoint, framePixmap.scaled(pixmap.width() + 10, pixmap.height() + 10));
         }
     }
