@@ -19,6 +19,7 @@
 */
 #include "kedittoolbar.h"
 #include "kedittoolbar_p.h"
+#include "debug.h"
 
 #include <QShowEvent>
 #include <QAction>
@@ -38,7 +39,6 @@
 #include <QStandardPaths>
 #include <QComboBox>
 #include <QLineEdit>
-#include <QDebug>
 
 #include <kicondialog.h>
 #include <klistwidgetsearchline.h>
@@ -51,6 +51,7 @@
 #include "kxmlguifactory.h"
 #include "ktoolbar.h"
 
+#include "ktoolbarhelper_p.h"
 #include "../kxmlgui_version.h"
 
 static const char separatorstring[] = I18N_NOOP("--- separator ---");
@@ -164,31 +165,13 @@ private:
 
 QString XmlData::toolBarText(const QDomElement &it) const
 {
-    const QLatin1String attrName("name");
-
-    QString name;
-    QByteArray txt(it.namedItem(QStringLiteral("text")).toElement().text().toUtf8());
-    if (txt.isEmpty()) {
-        txt = it.namedItem(QStringLiteral("text")).toElement().text().toUtf8();
-    }
-    if (txt.isEmpty()) {
-        name = it.attribute(attrName);
-    } else {
-        QByteArray domain = it.namedItem(QStringLiteral("text")).toElement().attribute(QStringLiteral("translationDomain")).toUtf8();
-        if (domain.isEmpty()) {
-            domain = it.ownerDocument().documentElement().attribute(QStringLiteral("translationDomain")).toUtf8();
-            if (domain.isEmpty()) {
-                domain = KLocalizedString::applicationDomain();
-            }
-        }
-        name = i18nd(domain.constData(), txt.constData());
-    }
+    QString name = KToolbarHelper::i18nToolBarName(it);
 
     // the name of the toolbar might depend on whether or not
     // it is in kparts
     if ((m_type == XmlData::Shell) ||
             (m_type == XmlData::Part)) {
-        QString doc_name(m_document.documentElement().attribute(attrName));
+        QString doc_name(m_document.documentElement().attribute(QStringLiteral("name")));
         name += QStringLiteral(" <") + doc_name + QLatin1Char('>');
     }
     return name;
@@ -306,7 +289,7 @@ ToolBarListWidget::ToolBarListWidget(QWidget *parent)
 QMimeData *ToolBarListWidget::mimeData(const QList<QListWidgetItem *> items) const
 {
     if (items.isEmpty()) {
-        return 0;
+        return nullptr;
     }
     QMimeData *mimedata = new QMimeData();
 
@@ -420,12 +403,12 @@ public:
                               const QString &cName, KActionCollection *collection)
         : m_collection(collection),
           m_widget(widget),
-          m_factory(NULL),
+          m_factory(nullptr),
           m_loadedOnce(false)
     {
         m_componentName = cName;
         m_isPart   = false;
-        m_helpArea = 0L;
+        m_helpArea = nullptr;
         // We want items with an icon to align with items without icon
         // So we use an empty QPixmap for that
         const int iconSize = widget->style()->pixelMetric(QStyle::PM_SmallIconSize);
@@ -473,7 +456,7 @@ public:
     {
         QString raw_xml;
         QString xml_file = xmlFile(_xml_file);
-        //qDebug() << "loadXMLFile xml_file=" << xml_file;
+        //qCDebug(DEBUG_KXMLGUI) << "loadXMLFile xml_file=" << xml_file;
 
         if (!QDir::isRelativePath(xml_file)) {
             raw_xml = KXMLGUIFactory::readConfigFile(xml_file);
@@ -563,7 +546,7 @@ class KEditToolBarPrivate
 public:
     KEditToolBarPrivate(KEditToolBar *q): q(q),
         m_accept(false), m_global(false),
-        m_collection(0), m_factory(0), m_widget(0) {}
+        m_collection(nullptr), m_factory(nullptr), m_widget(nullptr) {}
 
     void init();
 
@@ -612,7 +595,7 @@ KEditToolBar::KEditToolBar(KXMLGUIFactory *factory,
 void KEditToolBarPrivate::init()
 {
     m_accept = false;
-    m_factory = 0;
+    m_factory = nullptr;
 
     q->setDefaultToolBar(QString());
 
@@ -684,7 +667,7 @@ void KEditToolBarPrivate::defaultClicked()
     }
 
     KEditToolBarWidget *oldWidget = m_widget;
-    m_widget = 0;
+    m_widget = nullptr;
     m_accept = false;
 
     if (m_factory) {
@@ -697,7 +680,7 @@ void KEditToolBarPrivate::defaultClicked()
             // << "for client" << client << typeid(*client).name();
             if (QFile::exists(file))
                 if (!QFile::remove(file)) {
-                    qWarning() << "Could not delete" << file;
+                    qCWarning(DEBUG_KXMLGUI) << "Could not delete" << file;
                 }
         }
 
@@ -716,7 +699,7 @@ void KEditToolBarPrivate::defaultClicked()
 
         if (QFile::exists(xml_file))
             if (!QFile::remove(xml_file)) {
-                qWarning() << "Could not delete " << xml_file;
+                qCWarning(DEBUG_KXMLGUI) << "Could not delete " << xml_file;
             }
 
         m_widget = new KEditToolBarWidget(m_collection, q);
@@ -932,7 +915,7 @@ void KEditToolBarWidget::save()
             menuElement.setAttribute(QStringLiteral("noMerge"), QStringLiteral("1"));
         }
 
-        //qDebug() << (*it).domDocument().toString();
+        //qCDebug(DEBUG_KXMLGUI) << (*it).domDocument().toString();
 
         //qDebug(240) << "Saving " << (*it).xmlFile();
         // if we got this far, we might as well just save it
@@ -956,7 +939,7 @@ void KEditToolBarWidget::rebuildKXMLGUIClients()
     //qDebug(240) << "factory: " << clients.count() << " clients";
 
     // remove the elements starting from the last going to the first
-    if (!clients.count()) {
+    if (clients.isEmpty()) {
         return;
     }
 
@@ -1064,7 +1047,7 @@ void KEditToolBarWidgetPrivate::setupLayout()
     // "change icon text" button
     m_changeIconText = new QPushButton(i18n("Change Te&xt..."), m_widget);
     m_changeIconText->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
-    m_changeIconText->setEnabled(m_activeList->currentItem() != 0);
+    m_changeIconText->setEnabled(m_activeList->currentItem() != nullptr);
 
     QObject::connect(m_changeIconText, SIGNAL(clicked()),
                      m_widget, SLOT(slotChangeIconText()));
@@ -1282,7 +1265,7 @@ void KEditToolBarWidgetPrivate::loadActions(const QDomElement &elem)
     m_inactiveList->sortItems(Qt::AscendingOrder);
 
     // finally, add default separators to the inactive list
-    ToolBarItem *act = new ToolBarItem(0L, tagSeparator, sep_name.arg(sep_num++), QString());
+    ToolBarItem *act = new ToolBarItem(nullptr, tagSeparator, sep_name.arg(sep_num++), QString());
     act->setSeparator(true);
     act->setText(SEPARATORSTRING);
     m_inactiveList->insertItem(0, act);
@@ -1320,7 +1303,7 @@ void KEditToolBarWidgetPrivate::slotToolBarSelected(int index)
                 m_currentXmlData = & (*xit);
                 m_currentToolBarElem = *it;
 
-                //qDebug() << "found toolbar" << m_currentXmlData->toolBarText(*it) << "m_currentXmlData set to";
+                //qCDebug(DEBUG_KXMLGUI) << "found toolbar" << m_currentXmlData->toolBarText(*it) << "m_currentXmlData set to";
                 m_currentXmlData->dump();
 
                 // If this is a Merged xmldata, clicking the "change icon" button would assert...
@@ -1342,7 +1325,7 @@ void KEditToolBarWidgetPrivate::slotToolBarSelected(int index)
 
 void KEditToolBarWidgetPrivate::slotInactiveSelectionChanged()
 {
-    if (m_inactiveList->selectedItems().count()) {
+    if (!m_inactiveList->selectedItems().isEmpty()) {
         m_insertAction->setEnabled(true);
         QString statusText = static_cast<ToolBarItem *>(m_inactiveList->selectedItems().first())->statusText();
         m_helpArea->setText(i18nc("@label Action tooltip in toolbar editor, below the action list", "%1", statusText));
@@ -1354,7 +1337,7 @@ void KEditToolBarWidgetPrivate::slotInactiveSelectionChanged()
 
 void KEditToolBarWidgetPrivate::slotActiveSelectionChanged()
 {
-    ToolBarItem *toolitem = 0;
+    ToolBarItem *toolitem = nullptr;
     if (!m_activeList->selectedItems().isEmpty()) {
         toolitem = static_cast<ToolBarItem *>(m_activeList->selectedItems().first());
     }
@@ -1606,7 +1589,7 @@ void KEditToolBarWidgetPrivate::slotChangeIcon()
     }
 
     ToolBarItem *item = m_activeList->currentItem();
-    //qDebug() << item;
+    //qCDebug(DEBUG_KXMLGUI) << item;
     if (item) {
         item->setIcon(QIcon::fromTheme(icon));
 
@@ -1674,11 +1657,11 @@ void KEditToolBarWidgetPrivate::slotChangeIconText()
 
 void KEditToolBarWidgetPrivate::slotDropped(ToolBarListWidget *list, int index, ToolBarItem *item, bool sourceIsActiveList)
 {
-    //qDebug() << "slotDropped list=" << (list==m_activeList?"activeList":"inactiveList")
+    //qCDebug(DEBUG_KXMLGUI) << "slotDropped list=" << (list==m_activeList?"activeList":"inactiveList")
     //         << "index=" << index << "sourceIsActiveList=" << sourceIsActiveList;
     if (list == m_activeList) {
-        ToolBarItem *after = index > 0 ? static_cast<ToolBarItem *>(list->item(index - 1)) : 0;
-        //qDebug() << "after" << after->text() << after->internalTag();
+        ToolBarItem *after = index > 0 ? static_cast<ToolBarItem *>(list->item(index - 1)) : nullptr;
+        //qCDebug(DEBUG_KXMLGUI) << "after" << after->text() << after->internalTag();
         if (sourceIsActiveList) {
             // has been dragged within the active list (moved).
             moveActive(item, after);
